@@ -23,6 +23,25 @@ class MapillaryException(Exception):
     pass
 
 
+class InvalidBBoxError(MapillaryException):
+    """
+    Raised when an invalid coordinates for bounding box are entered
+    to access Mapillary's API.
+
+    :var message: The error message returned
+    :type message: str
+    """
+
+    def __init__(self, message: str):
+        self.message = message
+
+    def __str__(self):
+        return f'InvalidBBoxError: "{self.message}" '
+
+    def __repr__(self):
+        return f'InvalidBBoxError: = "{self.message}" '
+
+
 class InvalidTokenError(MapillaryException):
     """
     Raised when an invalid token is given
